@@ -467,7 +467,7 @@ class CyclicStrategy:
             for offset, task in tasks:
                 time = offset + cycles_offset + start
                 if integers:
-                    time = int(time)
+                    time = round(time)
 
                 # No further planning beyond this point.
                 if time > end:
